import { IGame } from './IGame';
import { GameSettings } from './types';
export declare abstract class GameBase implements IGame {
    private _step;
    private readonly _settings;
    protected constructor();
    get step(): number;
    get settings(): GameSettings;
    get hasReached(): boolean;
    protected abstract getSettings(): GameSettings;
    reset(): Promise<void>;
    protected abstract performReset(): Promise<void>;
    action(index: number): Promise<void> | never;
    protected abstract performAction(index: number): Promise<void>;
    perceive(index: number): Promise<boolean> | never;
    protected abstract performPerceive(index: number): Promise<boolean>;
    actionExpression(index: number): string;
    perceiveExpression(index: number): string;
    protected correctionItemScale(): number;
    getScore(): number;
    protected abstract performGetScore(): number;
    private static getCanvas;
    draw(target: string | HTMLCanvasElement): void;
    protected getBackgroundColor(): string;
    protected getPixelColor(x: number, y: number): [number, ...number[]] | undefined;
    protected parseColors(colors: [number, ...number[]]): {
        red: number;
        green: number;
        blue: number;
        alpha: number;
    };
    protected performDrawPixels(pixels: Uint8ClampedArray, width: number, height: number): void;
    protected performDraw(context: CanvasRenderingContext2D): void;
}
